DefaultLogInterceptor class

Implemented types

Constructors

DefaultLogInterceptor(void onLog(Object? data), {List<LogType> logTypes = const <LogType>[]})

Properties

hashCode → int
The hash code for this object.
no setterinherited
logTypes → List<LogType>
final
onLog → void Function(Object? data)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

log(Object? data, LogType logType) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited